//			Model 11 (see Table 1 of the paper)
//			To estimate over a specific period, change the datafile name in the estimation command.
//			Please cite our paper:
//			Benchimol, Jonathan and Fourçans, André, 2019. Central bank losses and monetary policy rules: a DSGE investigation.
//			International Review of Economics and Finance, Elsevier, Volume 61, Issue 1, Pages 289-303, May 2019.

var			labobs robs pinfobs dy dc dinve dw ewma epinfma zcapf rkf kf pkf cf invef yf labf wf rrf mc zcap rk k pk c inve y lab pinf wage_gap 
			w r a b g qs ms spinf sw kpf kp output_gap drate utils utilf welfs welff welfd price;
 
varexo		ea eb eg eqs em epinf ew;
 
parameters	curvw cgy curvp constelab constepinf constebeta cmaw cmap calfa 
			czcap csadjcost ctou csigma chabb cfc 
			cindw cprobw cindp cprobp csigl clandaw 
			crr cngdp 
			crhoa crhob crhog crhoqs crhoms crhopinf crhow 
			ctrend cg pstd;

// Fixed parameters
ctou		= 0.025;
clandaw		= 1.500;
cg			= 0.180;
curvp		= 10.00;
curvw		= 10.00;

// Estimated parameters initialisation
calfa		= 0.300;
cgamma		= 1.004;
cbeta		= 0.9975;
csigma		= 1.500;
cfc			= 1.250;
cgy			= 0.500;

csadjcost	= 4.000;
chabb		= 0.700;
cprobw		= 0.500;
csigl		= 2.000;
cprobp		= 0.500;
cindw		= 0.500;
cindp		= 0.500;
czcap		= 0.500;

crr			= 0.750;



cngdp		= 0.500;

crhoa		= 0.500;
crhob		= 0.500;
crhog		= 0.500;
crhols		= 0.500;
crhoqs		= 0.500;
crhoms		= 0.500;
crhopinf	= 0.500;
crhow		= 0.500;
cmap		= 0.500;
cmaw		= 0.500;
constelab	= 0.000;
pstd		= 1.000;

model;

#cpie		= 1+constepinf/100;
#cgamma		= 1+ctrend/100;
#cbeta		= 1/(1+constebeta/100);
#clandap	= cfc;
#cbetabar	= cbeta*cgamma^(-csigma);
#cr			= cpie/(cbeta*cgamma^(-csigma));
#crk		= (cbeta^(-1))*(cgamma^csigma) - (1-ctou);
#cw			= (calfa^calfa*(1-calfa)^(1-calfa)/(clandap*crk^calfa))^(1/(1-calfa));
#cikbar		= (1-(1-ctou)/cgamma);
#cik		= (1-(1-ctou)/cgamma)*cgamma;
#clk		= ((1-calfa)/calfa)*(crk/cw);
#cky		= cfc*(clk)^(calfa-1);
#ciy		= cik*cky;
#ccy		= 1-cg-cik*cky;
#crkky		= crk*cky;
#cwhlc		= (1/clandaw)*(1-calfa)/calfa*crk*cky/ccy;
#cwly		= 1-crk*cky;
#conster	= (cr-1)*100;

// Flexible economy

	// Marginal costs
	0*(1 - calfa)*a + 1*a = calfa*rkf + (1 - calfa)*wf;
	
	// Degree of capital utilization
	zcapf	= (1/(czcap/(1 - czcap)))*rkf;
	
	// Rental rate of capital
	rkf		= wf + labf - kf;
	
	// Current capital services used in production
	kf		= kpf(-1) + zcapf;
	
	// Investments
	invef	= (1/(1+cbetabar*cgamma))*(invef(-1) + cbetabar*cgamma*invef(+1) + (1/((cgamma^2)*csadjcost))*pkf) + qs;
	
	// Capital stock
	pkf		= -rrf - b + (crk/(crk + (1 - ctou)))*rkf(+1) + ((1 - ctou)/(crk + (1 - ctou)))*pkf(+1);
	
	// Consumption
	cf		= ((chabb/cgamma)/(1 + chabb/cgamma))*cf(-1) + (1/(1 + chabb/cgamma))*cf(+1) + ((csigma - 1)*cwhlc/(csigma*(1 + chabb/cgamma)))*(labf-labf(+1)) - (1 - chabb/cgamma)/(csigma*(1 + chabb/cgamma))*(rrf + b);

	// Output
	yf		= ccy*cf + ciy*invef + g + crkky*zcapf;
	yf		= cfc*(calfa*kf + (1 - calfa)*labf + a);
	
	// Wages
	wf		= csigl*labf + (1/(1 - chabb/cgamma))*cf - (chabb/cgamma)/(1 - chabb/cgamma)*cf(-1);
	
	// Capital accumulation
	kpf		= (1 - cikbar)*kpf(-1) + cikbar*invef + cikbar*((cgamma^2)*csadjcost)*qs;

// Sticky price - wage economy

	// Marginal costs
	mc		= calfa*rk + (1 - calfa)*w - 1*a - 0*(1 - calfa)*a;
	
	// Degree of capital utilization
	zcap	= (1/(czcap/(1 - czcap)))*rk;
	
	// Rental rate of capital
	rk		= w + lab - k;
	
	// Current capital services used in production
	k		= kp(-1) + zcap;
	
	// Investments
	inve	= (1/(1 + cbetabar*cgamma))*(inve(-1) + cbetabar*cgamma*inve(+1) + (1/((cgamma^2)*csadjcost))*pk) + qs;
	
	// Real value of the existing capital stock
	pk		= -r + pinf(+1) - b + (crk/(crk + (1 - ctou)))*rk(+1) + ((1 - ctou)/(crk + (1 - ctou)))*pk(+1);
	
	// Consumption
	c		= (chabb/cgamma)/(1 + chabb/cgamma)*c(-1) + (1/(1 + chabb/cgamma))*c(+1) +((csigma - 1)*cwhlc/(csigma*(1 + chabb/cgamma)))*(lab - lab(+1)) - (1 - chabb/cgamma)/(csigma*(1 + chabb/cgamma))*(r - pinf(+1) + b);

	// Ouptut
	y		= ccy*c + ciy*inve + g + 1*crkky*zcap;
	y		= cfc*(calfa*k + (1 - calfa)*lab + a);

	// Inflation
	pinf	= (1/(1 + cbetabar*cgamma*cindp)) * (cbetabar*cgamma*pinf(+1) + cindp*pinf(-1) 
			+((1 - cprobp)*(1 - cbetabar*cgamma*cprobp)/cprobp)/((cfc - 1)*curvp + 1)*(mc)) + spinf;

	// Wages
	w		= (1/(1 + cbetabar*cgamma))*w(-1)
			+(cbetabar*cgamma/(1 + cbetabar*cgamma))*w(+1)
			+(cindw/(1 + cbetabar*cgamma))*pinf(-1)
			-(1 + cbetabar*cgamma*cindw)/(1 + cbetabar*cgamma)*pinf
			+(cbetabar*cgamma)/(1 + cbetabar*cgamma)*pinf(+1)
			+(1 - cprobw)*(1 - cbetabar*cgamma*cprobw)/((1 + cbetabar*cgamma)*cprobw)*(1/((clandaw - 1)*curvw + 1))*
			(csigl*lab + (1/(1 - chabb/cgamma))*c - ((chabb/cgamma)/(1 - chabb/cgamma))*c(-1) - w) + 1*sw;

	// Monetary policy rule
	r		= (1 - crr)*(rrf + cngdp*(y - yf + price))
			+ crr*r(-1) + ms;

	output_gap	= y - yf;
	wage_gap	= w - wf;
	drate		= r - r(-1);
	
	// Total factor productivity (TFP)
	a		= crhoa*a(-1) + ea;
	
	// Risk premium shock
	b		= crhob*b(-1) + eb;
	
	// Government spendings
	g		= crhog*g(-1) + eg + cgy*ea;
	
	// Shock to investment-specific technology
	qs		= crhoqs*qs(-1) + eqs;
	
	// Monetary policy shock
	ms		= crhoms*ms(-1) + em;
	
	// ARMA price mark-up disturbance
	spinf	= crhopinf*spinf(-1) + epinfma - cmap*epinfma(-1);
	
	// Price mark-up shock
	epinfma	= epinf;
	
	// ARMA wage mark-up disturbance
	sw		= crhow*sw(-1) + ewma - cmaw*ewma(-1);
	
	// Wage mark-up shock
	ewma	= ew;
	
	// Capital accumulation
	kp		= (1 - cikbar)*kp(-1) + cikbar*inve + cikbar*(cgamma^2)*csadjcost*qs;

	// Welfare
	utils	= (1/(1-csigma))*((exp(c) - (chabb)*exp(c(-1)))^(1-csigma))*(exp(((csigma-1)/(1+csigl))*(exp(lab)^(1+csigl))));
	utilf	= (1/(1-csigma))*((exp(cf) - (chabb)*exp(cf(-1)))^(1-csigma))*(exp(((csigma-1)/(1+csigl))*(exp(labf)^(1+csigl))));
	welfs	= utils + cbeta*welfs(+1);
	welff	= utilf + cbeta*welff(+1);
	welfd	= welff - welfs;

// Measurment equations

	// Output
	dy		= y - y(-1) + ctrend;
	
	// Consumption
	dc		= c - c(-1) + ctrend;
	
	// Investment
	dinve	= inve - inve(-1) + ctrend;
	
	// Hourly wages
	dw		= w - w(-1) + ctrend;

	// Prices
	pinf	= 100*(price - price(-1));
	
	// Inflation rate
	pinfobs	= pinf + constepinf;
	
	// Interest rate
	robs	= 1*(r) + conster;
	
	// Worked hours
	labobs	= lab + constelab;

end;

shocks;
var ea;		stderr 0.100;
var eb;		stderr 0.100;
var eg;		stderr 0.100;
var eqs;	stderr 0.100;
var em;		stderr 0.100;
var epinf;	stderr 0.100;
var ew;		stderr 0.100;
end;

estimated_params;
csadjcost,		,		2,		15,			NORMAL_PDF,		4.00,	1.50*pstd;
csigma,			,		0.25,	3,			NORMAL_PDF,		1.50,	0.375*pstd;
chabb,			,		0.001,	0.99,		BETA_PDF,		0.70,	0.10*pstd;
cprobw,			,		0.3,	0.95,		BETA_PDF,		0.50,	0.10*pstd;
csigl,			,		0.25,	10,			NORMAL_PDF,		2.00,	0.75*pstd;
cprobp,			,		0.5,	0.95,		BETA_PDF,		0.50,	0.10*pstd;
cindw,			,		0.01,	0.99,		BETA_PDF,		0.50,	0.15*pstd;
cindp,			,		0.01,	0.99,		BETA_PDF,		0.50,	0.15*pstd;
czcap,			,		0.01,	1,			BETA_PDF,		0.50,	0.15*pstd;
cfc,			,		1.0,	3,			NORMAL_PDF,		1.25,	0.125*pstd;
crr,			,		0.5,	0.975,		BETA_PDF,		0.75,	0.10*pstd;




cngdp,			,		0.050,	0.95,		NORMAL_PDF,		0.500,	0.25*pstd;

constepinf,		,		0.1,	2.0,		GAMMA_PDF,		0.625,	0.10*pstd;
constebeta,		,		0.01,	2.0,		GAMMA_PDF,		0.250,	0.10*pstd;
constelab,		,		-10.0,	10.0,		NORMAL_PDF,		0.00,	2.00*pstd;
ctrend,			,		0.1,	0.8,		NORMAL_PDF,		0.40,	0.10*pstd;
cgy,			,		0.01,	2.0,		NORMAL_PDF,		0.50,	0.25*pstd;
calfa,			,		0.01,	1.0,		NORMAL_PDF,		0.30,	0.05*pstd;

crhoa,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhob,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhog,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhoqs,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhoms,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhopinf,		,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
crhow,			,		0.001,	0.9999,		BETA_PDF,		0.5,	0.20;
cmap,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;
cmaw,			,		0.01,	0.9999,		BETA_PDF,		0.5,	0.20;

stderr ea,		,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
stderr eb,		,		0.025,	5,			INV_GAMMA_PDF,		0.1,	2;
stderr eg,		,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
stderr eqs,		,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
stderr em,		,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
stderr epinf,	,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
stderr ew,		,		0.01,	3,			INV_GAMMA_PDF,		0.1,	2;
end;


varobs dy dc dinve labobs pinfobs dw robs;

// Estimation
estimation(order=1,filter_covariance,nograph,nodisplay,datafile=usdata0,mode_compute=6,filter_step_ahead=[1:12],bayesian_irf,forecast=12,filter_decomposition,lik_init=1,prefilter=0,mh_replic=6000000,mh_nblocks=2,mh_jscale=0.10,endogenous_prior) mc zcap rk k pk c inve y lab pinf w r g kp yf output_gap dy pinfobs robs drate utils utilf welfs welff welfd wf wage_gap;

shock_decomposition mc zcap rk k pk c inve y lab pinf w r g kp yf output_gap dy pinfobs robs drate utils utilf welfs welff welfd wf wage_gap;

// Generate IRFs and Moments of variables
stoch_simul(order=1,relative_irf,nograph,nodisplay,irf=40,conditional_variance_decomposition=[1,4,40]) mc zcap rk k pk c inve y lab pinf w r g kp yf output_gap dy pinfobs robs drate utils utilf welfs welff welfd wf wage_gap;