close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'all';

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels=1:12;

% Extracting estimation results
nbfilenames = 1:length(myfilenames);

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end
end

% Computing welfare functions

close all;
discarding = 8;
for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for km=nbmodels

for kv=1:length(myvariables)
RVariances (kv,kf,km) = eval(['oo' myfilenames{kf} num2str(km) '_.var(kv,kv)']);
RVariancesUpdated (kv,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.FilteredVariables.' myvariables{kv} '(1:length(xData))']) );
end
end
end

for kf=nbfilenames
for km=nbmodels
XLOSS(km,kf,1)=RVariances(10,kf,km);
XLOSS(km,kf,2)=RVariances(16,kf,km)/100;
XLOSS(km,kf,3)=RVariances(20,kf,km);
XLOSS(km,kf,4)=RVariances(11,kf,km)/100;

XLOSS(km,kf,11)=(RVariancesUpdated(10,kf,km));
XLOSS(km,kf,12)=(RVariancesUpdated(16,kf,km))/100;
XLOSS(km,kf,13)=(RVariancesUpdated(20,kf,km));
XLOSS(km,kf,14)=(RVariancesUpdated(11,kf,km))/100;
end
end

hFig1 = figure(1); clf; cla; 

	mygraph11 = subplot(4,4,1); bar(XLOSS(:,1,1),'b'); title('1955-2017','FontSize',10); grid on; axis tight; set(gca,'FontSize',10);
	ylabel('$var(\pi_{t})$','Interpreter','LaTex','FontSize',12);

	mygraph12 = subplot(4,4,2); bar(XLOSS(:,2,1),'b'); title('2007-2017','FontSize',10); grid on; axis tight; set(gca,'FontSize',10);

	mygraph13 = subplot(4,4,3); bar(XLOSS(:,3,1),'b'); title('1985-2007','FontSize',10); grid on; axis tight; set(gca,'FontSize',10);

	mygraph14 = subplot(4,4,4); bar(XLOSS(:,4,1),'b'); title('1955-1985','FontSize',10); grid on; axis tight; set(gca,'FontSize',10);

	linkaxes([mygraph11,mygraph12,mygraph13,mygraph14],'xy'); mygraph11.YLim = [0,max(max(XLOSS(:,:,1)))*1.1]; set(gca,'FontSize',10);
	

	mygraph21 = subplot(4,4,5); bar(XLOSS(:,1,2),'b'); grid on; axis tight; set(gca,'FontSize',10);
	ylabel('$var(y_{t} - y_{t}^{p})$','Interpreter','LaTex','FontSize',12);

	mygraph22 = subplot(4,4,6); bar(XLOSS(:,2,2),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph23 = subplot(4,4,7); bar(XLOSS(:,3,2),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph24 = subplot(4,4,8); bar(XLOSS(:,4,2),'b'); grid on; axis tight; set(gca,'FontSize',10);

	linkaxes([mygraph21,mygraph22,mygraph23,mygraph24],'xy'); mygraph21.YLim = [0,max(max(XLOSS(:,:,2)))*1.1]; set(gca,'FontSize',10);

	
	mygraph31 = subplot(4,4,9); bar(XLOSS(:,1,3),'b'); grid on; axis tight; set(gca,'FontSize',10);
	ylabel('$var(\triangle r_{t})$','Interpreter','LaTex','FontSize',12);


	mygraph32 = subplot(4,4,10); bar(XLOSS(:,2,3),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph33 = subplot(4,4,11); bar(XLOSS(:,3,3),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph34 = subplot(4,4,12); bar(XLOSS(:,4,3),'b'); grid on; axis tight; set(gca,'FontSize',10);

	linkaxes([mygraph31,mygraph32,mygraph33,mygraph34],'xy'); mygraph31.YLim = [0,max(max(XLOSS(:,:,3)))*1.1]; set(gca,'FontSize',10);

	mygraph41 = subplot(4,4,13); bar(XLOSS(:,1,4),'b'); grid on; axis tight; set(gca,'FontSize',10);
	ylabel('$var(w_{t})$','Interpreter','LaTex','FontSize',12);

	mygraph42 = subplot(4,4,14); bar(XLOSS(:,2,4),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph43 = subplot(4,4,15); bar(XLOSS(:,3,4),'b'); grid on; axis tight; set(gca,'FontSize',10);

	mygraph44 = subplot(4,4,16); bar(XLOSS(:,4,4),'b'); grid on; axis tight; set(gca,'FontSize',10);
	linkaxes([mygraph41,mygraph42,mygraph43,mygraph44],'xy'); mygraph41.YLim = [0,max(max(XLOSS(:,:,4)))*1.1]; set(gca,'FontSize',10);
	
	hold off;
	set(hFig1,'Position',[0 0 500 500]);
	hFig1.PaperUnits = 'inches';
	hFig1.PaperPosition = [0 0 11 9];
	set(gca,'FontSize',10);
	
f_name = strcat('fig_loss_estimated_',filename);
saveas(gcf,f_name,'epsc');


hFig3 = figure(3); clf; cla; 

	mygraph11 = subplot(4,4,1); bar(XLOSS(:,1,11),'b'); title('1955-2017','FontSize',10); grid on; axis tight;
	ylabel('$var(\pi_{t})$','Interpreter','LaTex','FontSize',10);

	mygraph12 = subplot(4,4,2); bar(XLOSS(:,2,11),'b'); title('2007-2017','FontSize',10); grid on; axis tight;

	mygraph13 = subplot(4,4,3); bar(XLOSS(:,3,11),'b'); title('1985-2007','FontSize',10); grid on; axis tight;

	mygraph14 = subplot(4,4,4); bar(XLOSS(:,4,11),'b'); title('1955-1985','FontSize',10); grid on; axis tight;

	linkaxes([mygraph11,mygraph12,mygraph13,mygraph14],'xy'); mygraph11.YLim = [0,max(max(XLOSS(:,:,11)))*1.1];
	

	mygraph21 = subplot(4,4,5); bar(XLOSS(:,1,12),'b'); grid on; axis tight;
	ylabel('$var(y_{t} - y_{t}^{p})$','Interpreter','LaTex','FontSize',10);

	mygraph22 = subplot(4,4,6); bar(XLOSS(:,2,12),'b'); grid on; axis tight;

	mygraph23 = subplot(4,4,7); bar(XLOSS(:,3,12),'b'); grid on; axis tight;

	mygraph24 = subplot(4,4,8); bar(XLOSS(:,4,12),'b'); grid on; axis tight;

	linkaxes([mygraph21,mygraph22,mygraph23,mygraph24],'xy'); mygraph21.YLim = [0,max(max(XLOSS(:,:,12)))*1.1];

	
	mygraph31 = subplot(4,4,9); bar(XLOSS(:,1,13),'b'); grid on; axis tight;
	ylabel('$var(\triangle r_{t})$','Interpreter','LaTex','FontSize',10);


	mygraph32 = subplot(4,4,10); bar(XLOSS(:,2,13),'b'); grid on; axis tight;

	mygraph33 = subplot(4,4,11); bar(XLOSS(:,3,13),'b'); grid on; axis tight;

	mygraph34 = subplot(4,4,12); bar(XLOSS(:,4,13),'b'); grid on; axis tight;

	linkaxes([mygraph31,mygraph32,mygraph33,mygraph34],'xy'); mygraph31.YLim = [0,max(max(XLOSS(:,:,13)))*1.1];

	mygraph41 = subplot(4,4,13); bar(XLOSS(:,1,14),'b'); grid on; axis tight;
	ylabel('$var(w_{t})$','Interpreter','LaTex','FontSize',10);

	mygraph42 = subplot(4,4,14); bar(XLOSS(:,2,14),'b'); grid on; axis tight;

	mygraph43 = subplot(4,4,15); bar(XLOSS(:,3,14),'b'); grid on; axis tight;

	mygraph44 = subplot(4,4,16); bar(XLOSS(:,4,14),'b'); grid on; axis tight;
	linkaxes([mygraph41,mygraph42,mygraph43,mygraph44],'xy'); mygraph41.YLim = [0,max(max(XLOSS(:,:,14)))*1.1];
	%set(gca,'FontSize',8);
f_name = strcat('fig_loss_computed_',filename);
saveas(gcf,f_name,'epsc');


close all; clear all; clc;
