close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fig_index=1;

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels=1:12;

% Extracting estimation results
nbfilenames = 1:length(myfilenames);

close all;

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for i = 1:length(forecasters)
      % compose a command to assign each column to a variable with the same name as the header
      commandExec = [forecasters{i}, ' = ', 'forecast_values(:,', num2str(i) , ');'];
      % execute the composed command to actually create the variable
      evalin('base', commandExec );
end

for km = nbmodels
for mytime=1:length(xData)
estimated_output(km,mytime,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.y(mytime)']);
flexible_output(km,mytime,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.yf(mytime)']);
end
for mytime=2:length(xData)
dflexible_output(km,mytime,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.yf(mytime)'])-eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.yf(mytime-1)'])+eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.ctrend']);
dactual_output(km,mytime,kf)=eval(['dy(mytime)']);
estimated_output2(km,1,kf)=dactual_output(km,1,kf)+eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.ctrend']);
estimated_output2(km,mytime,kf)=dactual_output(km,mytime,kf)+estimated_output2(km,mytime-1,kf);
flexible_output2(km,1,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.yf(1)'])+eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.ctrend']);
flexible_output2(km,mytime,kf)=dflexible_output(km,mytime,kf)+flexible_output2(km,mytime-1,kf);
end
end

hFig1 = figure(fig_index); clf; fig_index=fig_index+1;

ha = tight_subplot(4,3,[.0 .055],[.05 .01],[.05 .01]);

for km=nbmodels
	axes(ha(km)); b = plot(xData,[0,dflexible_output(km,2:length(xData),kf)],'--',xData,[0,dactual_output(km,2:length(xData),kf)],'-','LineWidth',1);
	axis tight; grid on; ylim([min(min(min(dflexible_output(:,2:length(xData),kf))),min(min(dactual_output(:,2:length(xData),kf)))) max(max(max(dflexible_output(:,2:length(xData),kf))),max(max(dactual_output(:,2:length(xData),kf))))]);
	h = legend(['Model ', num2str(km)]); set(h,'Location','best','FontSize',10,'Box','off');
set(ha(1:9),'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
set(ha(10:12),'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
datetick('x','YYQQ','keepticks');

correlation_y_yf_int = corrcoef(dflexible_output(km,2:length(xData),kf),dactual_output(km,2:length(xData),kf));
correlation_y_yf(km,kf) = correlation_y_yf_int(2);

covariance_y_yf_int = cov(dflexible_output(km,2:length(xData),kf),dactual_output(km,2:length(xData),kf));
covariance_y_yf(km,kf) = covariance_y_yf_int(2);

variance_y(km,kf) = var(dactual_output(km,2:length(xData),kf));
variance_yf(km,kf) = var(dflexible_output(km,2:length(xData),kf));

end

f_name = strcat('fig_output_comparison_',myfilenames{kf});
saveas(gcf,f_name,'epsc');

hFig2 = figure(fig_index); clf; fig_index=fig_index+1;

ha = tight_subplot(4,3,[.0 .055],[.05 .01],[.05 .01]);

for km=nbmodels
	axes(ha(km)); b = plot(xData,[0,flexible_output2(km,2:length(xData),kf)],'--',xData,[0,estimated_output2(km,2:length(xData),kf)],'-','LineWidth',1);
	axis tight; grid on; ylim([min(min(min(flexible_output2(:,2:length(xData),kf))),min(min(estimated_output2(:,2:length(xData),kf)))) max(max(max(flexible_output2(:,2:length(xData),kf))),max(max(estimated_output2(:,2:length(xData),kf))))]);
	h = legend(['Model ', num2str(km)]); set(h,'Location','best','FontSize',10,'Box','off');
set(ha(1:9),'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
set(ha(10:12),'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
datetick('x','YYQQ','keepticks');
end

f_name = strcat('fig_output_comparison_level_',myfilenames{kf});
saveas(gcf,f_name,'epsc');
end

xlswrite('correlation_y_yf',correlation_y_yf);
xlswrite('covariance_y_yf',covariance_y_yf);
xlswrite('variance_y',variance_y);
xlswrite('variance_yf',variance_yf);
