close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'all';

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myparamstodisplay={
'calfa',
'chabb',
'cprobp',
'cprobw',
'cindp',
'cindw',
'crhoa',
'crhob',
'crhog',
'crhoqs',
'crhoms',
'crhopinf',
'crhow',
'cmap',
'cmaw'
};

myshocks={
'ea',
'eb',
'eqs',
'em',
'epinf',
'ew',
'eg'
};

myperiods={
'1955-2017',
'2007-2017',
'1985-2007',
'1955-1985'
};

nbmodels = 1:12;
fig_index = 1;

% Extracting estimation results
nbparameters = 1:length(myparamstodisplay);
nbfilenames = 1:length(myfilenames);
nbshocks = 1:length(myshocks);

for kf = nbfilenames
for km = nbmodels

for kp = nbparameters
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
	if(isfield(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters']),myparamstodisplay{kp})==1)
	REstimationsMean (km,kp,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.' myparamstodisplay{kp}]));
	REstimationsStd (km,kp,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_std.parameters.' myparamstodisplay{kp}]));
	REstimationsInf (km,kp,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_hpdinf.parameters.' myparamstodisplay{kp}]));
	REstimationsSup (km,kp,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_hpdsup.parameters.' myparamstodisplay{kp}]));
	end
end

for ks = nbshocks
	REstimationsMeanS (km,ks,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.shocks_std.' myshocks{ks}]));
	REstimationsStdS (km,ks,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_std.shocks_std.' myshocks{ks}]));
	REstimationsInfS (km,ks,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_hpdinf.shocks_std.' myshocks{ks}]));
	REstimationsSupD (km,ks,kf) = real(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_hpdsup.shocks_std.' myshocks{ks}]));
end

end
end

close all;
for kf = nbfilenames
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'$\alpha$','$\lambda$','$\xi _{p}$','$\xi _{w}$','$\iota _{p}$','$\iota _{w}$','$\rho _{a}$','$\rho _{b}$','$\rho _{g}$','$\rho _{ga}$','$\rho _{r}$','$\rho _{p}$','$\rho _{w}$','$\mu _{p}$','$\mu _{w}$'};
h=heatmap(xvalues,yvalues,REstimationsStd(nbmodels,:,kf)','Colormap',colormap(flipud(gray)));
h.ColorScaling = 'scaledrows';
colorbar('off');
h.Title = myperiods{kf};
h.XLabel = 'Models';
%h.YLabel = 'Output gap and interest rate weights';
h.CellLabelFormat = '%.2f';
h.GridVisible = 'off';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = xvalues;
hs.XAxis.TickLabelInterpreter = 'none';
hs.YAxis.TickValues = yvalues;
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;

f_name = strcat('fig_parameters_std_hm_',myfilenames{kf});
saveas(gcf,f_name,'epsc');
end


hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues{1} = {'$\xi _{p}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{2} = {'$\xi _{w}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{3} = {'$\iota _{p}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{4} = {'$\iota _{w}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
for kkk=1:4
subplot(4,1,kkk); h = heatmap(xvalues,yvalues{kkk},squeeze([REstimationsStd(nbmodels,kkk+2,:)])','Colormap',colormap(flipud(gray)));
h.GridVisible = 'off';h.CellLabelFormat = '%.2f';colorbar('off');h.ColorScaling = 'scaledrows';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = [];
hs.XAxis.TickLabelInterpreter = 'latex';
hs.YAxis.TickValues = yvalues{kkk};
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;
end%hs.XAxis.TickValues = xvalues;

f_name = strcat('fig_parameters_std_hm_subplot1');
saveas(gcf,f_name,'epsc');


hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues{1} = {'$\xi _{p}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{2} = {'$\xi _{w}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{3} = {'$\iota _{p}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{4} = {'$\iota _{w}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
for kkk=1:4
subplot(4,1,kkk); h = heatmap(xvalues,yvalues{kkk},squeeze([REstimationsMean(nbmodels,kkk+2,:)])','Colormap',colormap(flipud(gray)));
h.GridVisible = 'off';h.CellLabelFormat = '%.2f';colorbar('off');h.ColorScaling = 'scaledrows';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = [];
hs.XAxis.TickLabelInterpreter = 'latex';
hs.YAxis.TickValues = yvalues{kkk};
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;
end%hs.XAxis.TickValues = xvalues;

f_name = strcat('fig_parameters_mean_hm_subplot1');
saveas(gcf,f_name,'epsc');



hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues{1} = {'$\varepsilon _{t}^{a}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{2} = {'$\varepsilon _{t}^{b}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{3} = {'$\varepsilon _{t}^{i}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{4} = {'$\varepsilon _{t}^{r}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{5} = {'$\varepsilon _{t}^{\pi}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
yvalues{6} = {'$\varepsilon _{t}^{w}$ 1955-2017', '2007-2017', '1985-2007', '1955-1985'};
for kkk=1:6
subplot(6,1,kkk); h = heatmap(xvalues,yvalues{kkk},squeeze([REstimationsMeanS(nbmodels,kkk,:)])','Colormap',colormap(flipud(gray)));
h.GridVisible = 'off';h.CellLabelFormat = '%.2f';colorbar('off');h.ColorScaling = 'scaledrows';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = [];
hs.XAxis.TickLabelInterpreter = 'latex';
hs.YAxis.TickValues = yvalues{kkk};
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;
end%hs.XAxis.TickValues = xvalues;

f_name = strcat('fig_parameters_mean_hm_subplot2');
saveas(gcf,f_name,'epsc');

for theparam=nbparameters
for thekf=1:4
for themodel=nbmodels

thetable1((thekf*2)-1,themodel)=REstimationsMean(themodel,theparam,thekf);
thetable1((thekf*2),themodel)=REstimationsStd(themodel,theparam,thekf);

SWP3(thetable1,[myparamstodisplay{theparam}]);
end
end
delete thetable1;
end
% SWP5(REstimationsMeanS(nbmodels,4,:)',['ShockMeans']);
% SWP5(REstimationsStdS(nbmodels,4,:)',['ShockStds']);
% SWP5(REstimationsMeanS(nbmodels,5,:)',['ShockMeans']);
% SWP5(REstimationsStdS(nbmodels,5,:)',['ShockStds']);
% SWP5(REstimationsMeanS(nbmodels,6,:)',['ShockMeans']);
% SWP5(REstimationsStdS(nbmodels,6,:)',['ShockStds']);
% SWP5(REstimationsMeanS(nbmodels,3,1)',['ShockMeans']);
% SWP5(REstimationsStdS(nbmodels,:,1)',['ShockStds']);
