close all; clc; clear all;
%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myparamstodisplay={
'crr',
'crpi',
'cry',
'crdy',
'cngdp'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels=1:12;

fig_index=1;

% Extracting estimation results
nbparameters = 1:length(myparamstodisplay);
nbfilenames = 1:length(myfilenames);

close all;

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for i = 1:length(forecasters)
      % compose a command to assign each column to a variable with the same name as the header
      commandExec = [forecasters{i}, ' = ', 'forecast_values(:,', num2str(i) , ');'];
      % execute the composed command to actually create the variable
      evalin('base', commandExec );
end

for km = nbmodels

cpie(km)			= 1+(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.constepinf'])/100);
cgamma(km)			= 1+(eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.ctrend'])/100);
csigma(km)			= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.csigma']);
constebeta(km)		= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.constebeta']);
cbeta(km)			= 1/((constebeta(km)/100)+1);
cr(km)				= cpie(km)/(cbeta(km)*cgamma(km)^(-csigma(km)));
conster(km)			= (cr(km) - 1)*100;

for mytime=1:length(xData)
rulem(km,mytime,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.r(mytime)'])-eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.ms(mytime)'])+conster(km);%
%rulem(km,mytime,kf)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.r(mytime)'])+conster(km);%
end

end

hFig1 = figure(fig_index); clf; fig_index=fig_index+1;

ha = tight_subplot(4,3,[.0 .055],[.05 .01],[.05 .01]);

for km=nbmodels
	axes(ha(km)); b = plot(xData,rulem(km,1:length(xData),kf),'--',xData,robs(1:length(xData)),'-','LineWidth',1);%+conster(km),'-b',xData,robs(1:length(xData)),'--k',xData,0,'-r'   % xData,[zeros(1,length(xData));zeros(1,length(xData))+0.25;zeros(1,length(xData))+0.5;zeros(1,length(xData))-0.25;zeros(1,length(xData))-0.5],'--',
	axis tight; grid on; ylim([min(min(min(rulem(:,1:length(xData),kf))),min(min(rulem(:,1:length(xData),kf)))) max(max(max(rulem(:,1:length(xData),kf))),max(max(rulem(:,1:length(xData),kf))))]);
	h = legend(['Model ', num2str(km)],'History'); set(h,'Location','best','FontSize',10,'Box','off');
set(ha(1:9),'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
set(ha(10:12),'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
datetick('x','YYQQ','keepticks');
end

f_name = strcat('fig_rule_comparison_',myfilenames{kf});
saveas(gcf,f_name,'epsc');

hFig2 = figure(fig_index); clf; fig_index=fig_index+1;

ha1 = tight_subplot(1,1,[.0 .055],[.05 .01],[.05 .01]);

	axes(ha1); b = plot(xData,(rulem(1,1:length(xData),kf)+rulem(2,1:length(xData),kf)+rulem(3,1:length(xData),kf)+rulem(4,1:length(xData),kf)+rulem(5,1:length(xData),kf)+rulem(6,1:length(xData),kf)+rulem(7,1:length(xData),kf)+rulem(8,1:length(xData),kf)+rulem(9,1:length(xData),kf))/9,'--',xData,robs(1:length(xData)),'-','LineWidth',1);
	axis tight; grid on; ylim([min(min(min(rulem(:,1:length(xData),kf))),min(min(rulem(:,1:length(xData),kf)))) max(max(max(rulem(:,1:length(xData),kf))),max(max(rulem(:,1:length(xData),kf))))]);
	h = legend(['Suite of models '],'History'); set(h,'Location','best','FontSize',10,'Box','off');
set(ha1,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
datetick('x','YYQQ','keepticks');

f_name = strcat('fig_rule_comparison_som_',myfilenames{kf});
saveas(gcf,f_name,'epsc');

end
