close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'all';

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myparams={
'csadjcost',
'csigma',
'chabb',
'cprobw',
'csigl',
'cprobp',
'cindw',
'cindp',
'czcap',
'cfc',
'crr',
'crpi',
'cry',
'crdy',
'cngdp',
'constepinf',
'constelab',
'ctrend',
'cgy',
'calfa',
'crhoa',
'crhob',
'crhog',
'crhoqs',
'crhoms',
'crhopinf',
'crhow',
'cmap',
'cmaw',

'ea',
'eb',
'eg',
'eqs',
'em',
'epinf',
'ew'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels=1:12;

% Extracting estimation results
nbfilenames = 1:length(myfilenames);

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end
end

% Computing welfare functions

close all;
%discarding = 8;
for kf = nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for i = 1:length(forecasters)
      % compose a command to assign each column to a variable with the same name as the header
      commandExec = [forecasters{i}, ' = ', 'forecast_values(:,', num2str(i) , ');'];
      % execute the composed command to actually create the variable
      evalin('base', commandExec );
end

for km = nbmodels

csigma(km)			= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.csigma']);
constebeta(km)		= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.constebeta']);
cbeta(km)			= 1/((constebeta(km)/100)+1);

WelfareUs(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.' myvariables{23} '(:)']));
WelfareUf(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.' myvariables{24} '(:)']));
WelfareSs(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.SmoothedVariables.' myvariables{23} '(:)']));
WelfareSf(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.SmoothedVariables.' myvariables{24} '(:)']));
WelfareFs(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.FilteredVariables.' myvariables{23} '(:)']));
WelfareFf(km,kf)=sum(eval(['oo' myfilenames{kf} num2str(km) '_.FilteredVariables.' myvariables{24} '(:)']));
WelfareUl(km,kf)=1/(((WelfareUf(km,kf)/WelfareUs(km,kf))^(1/(1-csigma(km))))+1);
WelfareSl(km,kf)=1/(((WelfareSf(km,kf)/WelfareSs(km,kf))^(1/(1-csigma(km))))+1);
WelfareFl(km,kf)=1/(((WelfareFf(km,kf)/WelfareFs(km,kf))^(1/(1-csigma(km))))+1);
% WelfareUl(km,kf)=((log(WelfareUf(km,kf)-WelfareUs(km,kf)))*(1/(1-csigma(km))));
% WelfareSl(km,kf)=((log(WelfareSf(km,kf)-WelfareSs(km,kf)))*(1/(1-csigma(km))));
% WelfareFl(km,kf)=((log(WelfareFf(km,kf)-WelfareFs(km,kf)))*(1/(1-csigma(km))));
end

end
% Welfare function: Indexed versus nominal government debt under inflation and price-level targeting Michael Hatcher JEDC
% Welfare function: Real wage rigidities and optimal monetary policy in a small open economy Hyuk Jae Rhee Jeongseok Song

close all;
fig_index=1;
set(0, 'DefaultAxesColorOrder',[0 0 0;1 0 0;0 1 0;0 0 1], 'DefaultAxesLineStyleOrder','-|--|:')

hFig1 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{24} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{23} '(1:length(xData))'])); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 40],'nrow',2,'fontsize',10,'box',['off']);

MyWelfareF0(kf,nbmodels)=WelfareFl(nbmodels,kf);
MyWelfareF1(kf,nbmodels)=WelfareFs(nbmodels,kf);
MyWelfareF2(kf,nbmodels)=WelfareFf(nbmodels,kf);
xlswrite('welfare',MyWelfareF0,1);
xlswrite('welfare',MyWelfareF1,2);
xlswrite('welfare',MyWelfareF2,3);
MyWelfareS0(kf,nbmodels)=WelfareSl(nbmodels,kf);
MyWelfareS1(kf,nbmodels)=WelfareSs(nbmodels,kf);
MyWelfareS2(kf,nbmodels)=WelfareSf(nbmodels,kf);
xlswrite('welfare',MyWelfareS0,4);
xlswrite('welfare',MyWelfareS1,5);
xlswrite('welfare',MyWelfareS2,6);
MyWelfareU0(kf,nbmodels)=WelfareUl(nbmodels,kf);
MyWelfareU1(kf,nbmodels)=WelfareUs(nbmodels,kf);
MyWelfareU2(kf,nbmodels)=WelfareUf(nbmodels,kf);
xlswrite('welfare',MyWelfareU0,7);
xlswrite('welfare',MyWelfareU1,8);
xlswrite('welfare',MyWelfareU2,9);

end

f_name = strcat('fig_welfare_losses_',filename);
saveas(gcf,f_name,'epsc');


hFig2 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{23} '(1:length(xData))']),xData,eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{23} '(1:length(xData))'])); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 40],'nrow',2,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_welfare_',filename);
saveas(gcf,f_name,'epsc');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hFig3 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,(eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2,xData,(eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])-0.5).^2); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 40],'nrow',2,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_inflation_gap_loss_',filename);
saveas(gcf,f_name,'epsc');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hFig4 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,(eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100,xData,(eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{16} '(1:length(xData))']).^2)/100); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 40],'nrow',2,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_output_gap_loss_',filename);
saveas(gcf,f_name,'epsc');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hFig5 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,(eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2),xData,(eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{20} '(1:length(xData))']).^2)); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',2,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_interest_gap_loss_',filename);
saveas(gcf,f_name,'epsc');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

hFig6 = figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,((eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100,xData,((eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])-eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{25} '(1:length(xData))'])).^2)/100); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5),'FontSize',8);
	datetick('x','YYQQ','keepticks');
	
	lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 40],'nrow',2,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_wage_gap_loss_',filename);
saveas(gcf,f_name,'epsc');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,((eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{11} '(1:length(xData))'])).^2)/4); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	datetick('x','YYQQ','keepticks');
	
	lbl = {'Taylor type (1 to 4) ','NGDP growth type (5 to 8) ','NGDP level type (9 to 12) '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',1,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_wage_gap_loss_avg_',filename);
saveas(gcf,f_name,'epsc');







figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,((eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{16} '(1:length(xData))'])).^2)/4); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	datetick('x','YYQQ','keepticks');
	
	lbl = {'Taylor type (1 to 4) ','NGDP growth type (5 to 8) ','NGDP level type (9 to 12) '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',1,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_output_gap_loss_avg_',filename);
saveas(gcf,f_name,'epsc');





figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,((eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{20} '(1:length(xData))'])).^2)/4); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	datetick('x','YYQQ','keepticks');
	
	lbl = {'Taylor type (1 to 4) ','NGDP growth type (5 to 8) ','NGDP level type (9 to 12) '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',1,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_interest_rate_loss_avg_',filename);
saveas(gcf,f_name,'epsc');








figure(fig_index); clf; cla; fig_index=fig_index+1;

for kf=nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

	mygraph(kf) = subplot(2,2,kf);
	b = plot(xData,((eval(['oo' myfilenames{kf} num2str(1) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(2) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(3) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(4) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(5) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(6) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(7) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(8) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])).^2)/4,xData,((eval(['oo' myfilenames{kf} num2str(9) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(10) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(11) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])+eval(['oo' myfilenames{kf} num2str(12) '_.FilteredVariables.' myvariables{10} '(1:length(xData))'])).^2)/4); grid on; axis tight;
	title(myperiods{kf},'FontSize',10);
	set(gca,'XTickLabel','','xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	set(gca,'xlim',[startDate endDate],'XTick',linspace(startDate,endDate,5));
	datetick('x','YYQQ','keepticks');
	
	lbl = {'Taylor type (1 to 4) ','NGDP growth type (5 to 8) ','NGDP level type (9 to 12) '};
	legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',1,'fontsize',10,'box',['off']);

end

f_name = strcat('fig_inflation_gap_loss_avg_',filename);
saveas(gcf,f_name,'epsc');