close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'all';

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myparams={
'csadjcost',
'csigma',
'chabb',
'cprobw',
'csigl',
'cprobp',
'cindw',
'cindp',
'czcap',
'cfc',
'crr',
'crpi',
'cry',
'crdy',
'cngdp',
'constepinf',
'constelab',
'ctrend',
'cgy',
'calfa',
'crhoa',
'crhob',
'crhog',
'crhoqs',
'crhoms',
'crhopinf',
'crhow',
'cmap',
'cmaw',

'ea',
'eb',
'eg',
'eqs',
'em',
'epinf',
'ew'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels=1:12;

% Extracting estimation results
nbfilenames = 1:length(myfilenames);

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end
end

% Computing welfare functions

close all;
%discarding = 8;
for kf = nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for i = 1:length(forecasters)
      % compose a command to assign each column to a variable with the same name as the header
      commandExec = [forecasters{i}, ' = ', 'forecast_values(:,', num2str(i) , ');'];
      % execute the composed command to actually create the variable
      evalin('base', commandExec );
end

for km = nbmodels

csigma(km)			= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.csigma']);
constebeta(km)		= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.constebeta']);
cbeta(km)			= 1/((constebeta(km)/100)+1);

for kv=1:length(myvariables)
RVariances (kv,kf,km) = eval(['oo' myfilenames{kf} num2str(km) '_.var(kv,kv)']);
RVariancesUpdated (kv,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.FilteredVariables.' myvariables{kv} '(1:length(xData))']) );
end

for ii = 1:length(xData)
WelfareUst(km,kf,ii)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.' myvariables{23} '(ii)']);
WelfareUft(km,kf,ii)=eval(['oo' myfilenames{kf} num2str(km) '_.UpdatedVariables.' myvariables{24} '(ii)']);
end

WelfareUs(km,kf)=sum(WelfareUst(km,kf,:));
WelfareUf(km,kf)=sum(WelfareUft(km,kf,:));

end

end

close all; clear all;