close all; clc; clear all;

%%%%%%%%%%%%%%%%% CONFIGURATION ZONE %%%%%%%%%%%%%%%%%
% Select period
addpath(genpath('tools/'));
addpath(genpath('data/us0_cr/'));
addpath(genpath('data/us1_sr/'));
addpath(genpath('data/us2/'));
addpath(genpath('data/us3/'));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'all';

myfilenames={
'us0',
'us1',
'us2',
'us3'
};

myparams={
'csadjcost',
'csigma',
'chabb',
'cprobw',
'csigl',
'cprobp',
'cindw',
'cindp',
'czcap',
'cfc',
'crr',
'crpi',
'cry',
'crdy',
'cngdp',
'constepinf',
'constelab',
'ctrend',
'cgy',
'calfa',
'crhoa',
'crhob',
'crhog',
'crhoqs',
'crhoms',
'crhopinf',
'crhow',
'cmap',
'cmaw',

'ea',
'eb',
'eg',
'eqs',
'em',
'epinf',
'ew'
};

myvariables={
'mc',
'zcap',
'rk',
'k',
'pk',
'c',
'inve',
'y',
'lab',
'pinf',
'w',
'r',
'g',
'kp',
'yf',
'output_gap',
'dy',
'pinfobs',
'robs',
'drate',
'utils',
'utilf',
'welfs',
'welff',
'welfd',
'wf',
'wage_gap'
};

myperiods={
{'Sample: 1955-2017'},
{'Sample: 2007-2017'},
{'Sample: 1985-2007'},
{'Sample: 1955-1985'}
};

nbmodels	= 1:12;
nbshocks	= 1:7;
nbirfs		= 1:30;

% Extracting estimation results
nbfilenames = 1:length(myfilenames);

for kf = nbfilenames
for km = nbmodels
	load(sprintf([myfilenames{kf} '%01.0f_oo.mat'], km));
end
end

% Computing welfare functions

close all;
%discarding = 8;
for kf = nbfilenames

if kf==1
startDate = datenum(1955,01,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,248); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata0.xlsx',1);
elseif kf==2
startDate = datenum(2007,04,01);
endDate = datenum(2017,01,01);
xData = linspace(startDate,endDate,40); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata1.xlsx',1);
elseif kf==3
startDate = datenum(1985,04,01);
endDate = datenum(2007,01,01);
xData = linspace(startDate,endDate,88); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata2.xlsx',1);
elseif kf==4
startDate = datenum(1955,01,01);
endDate = datenum(1984,12,01);
xData = linspace(startDate,endDate,120); % Length of filtered variables
[forecast_values,forecasters] = xlsread('usdata3.xlsx',1);
end

for i = 1:length(forecasters)
      % compose a command to assign each column to a variable with the same name as the header
      commandExec = [forecasters{i}, ' = ', 'forecast_values(:,', num2str(i) , ');'];
      % execute the composed command to actually create the variable
      evalin('base', commandExec );
end

for km = nbmodels

csigma(km)			= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.csigma']);
constebeta(km)		= eval(['oo' myfilenames{kf} num2str(km) '_.posterior_mean.parameters.constebeta']);
cbeta(km)			= 1/((constebeta(km)/100)+1);

for kv=1:length(myvariables)
RVariances (kv,kf,km) = eval(['oo' myfilenames{kf} num2str(km) '_.var(kv,kv)']);
RVariancesUpdated (kv,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.FilteredVariables.' myvariables{kv} '(1:length(xData))']) );
end
RVariancesIRFs (2,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.irfs.pinf_epinf(1:40)']) );
RVariancesIRFs (3,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.irfs.output_gap_epinf(1:40)']) );
RVariancesIRFs (4,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.irfs.drate_epinf(1:40)']) );
RVariancesIRFs (5,kf,km) = var( eval(['oo' myfilenames{kf} num2str(km) '_.irfs.w_epinf(1:40)']) );

end

end
% Welfare function: Indexed versus nominal government debt under inflation and price-level targeting Michael Hatcher JEDC
% Welfare function: Real wage rigidities and optimal monetary policy in a small open economy Hyuk Jae Rhee Jeongseok Song

for kf=nbfilenames
for km=nbmodels

for pog=1:5
for pdr=1:5
for pwi=1:5
WelfareIRF(km,kf,pog,pdr,pwi)	= sqrt(RVariancesIRFs (2,kf,km)+(((pog-1)/4).*RVariancesIRFs (3,kf,km))+(((pdr-1)/4).*RVariancesIRFs (4,kf,km))+(((pwi-1)/4).*RVariancesIRFs (5,kf,km)))/100;
end
end
end

end
end

close all;

fig_index = 1;

for kf=nbfilenames

% no rate and wage weight
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0','0.25','0.5','0.75','1'};
h = heatmap(xvalues,yvalues,squeeze(WelfareIRF(nbmodels,kf,1:5,1,1))','Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss weights';
%h.XLabel = 'Models';
h.YLabel = 'Output gap weights';
f_name = strcat('fig_welfare_hm00_',num2str(kf));
print(f_name,'-depsc2','-r0');

% no wage weight
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0','0.25','0.5','0.75','1'};
h = heatmap(xvalues,yvalues,squeeze(WelfareIRF(nbmodels,kf,1:5,5,1))','Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss weights';
%h.XLabel = 'Models';
h.YLabel = 'Output gap weights';
f_name = strcat('fig_welfare_hm10_',num2str(kf));
print(f_name,'-depsc2','-r0');

% no rate weight
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0','0.25','0.5','0.75','1'};
h = heatmap(xvalues,yvalues,squeeze(WelfareIRF(nbmodels,kf,1:5,1,5))','Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss weights';
%h.XLabel = 'Models';
h.YLabel = 'Output gap weights';
f_name = strcat('fig_welfare_hm01_',num2str(kf));
print(f_name,'-depsc2','-r0');

% all weights
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0','0.25','0.5','0.75','1'};
h = heatmap(xvalues,yvalues,squeeze(WelfareIRF(nbmodels,kf,1:5,5,5))','Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss weights';
%h.XLabel = 'Models';
h.YLabel = 'Output gap weights';
f_name = strcat('fig_welfare_hm11_',num2str(kf));
print(f_name,'-depsc2','-r0');


% all interest rate 
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'$\lambda_{y}$=0.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.25 $\lambda_{r}$=0.00','$\lambda_{y}$=0.50 $\lambda_{r}$=0.00','$\lambda_{y}$=0.75 $\lambda_{r}$=0.00','$\lambda_{y}$=1.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.25 $\lambda_{r}$=0.25','$\lambda_{y}$=0.50 $\lambda_{r}$=0.25','$\lambda_{y}$=0.75 $\lambda_{r}$=0.25','$\lambda_{y}$=1.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.25 $\lambda_{r}$=0.50','$\lambda_{y}$=0.50 $\lambda_{r}$=0.50','$\lambda_{y}$=0.75 $\lambda_{r}$=0.50','$\lambda_{y}$=1.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.25 $\lambda_{r}$=0.75','$\lambda_{y}$=0.50 $\lambda_{r}$=0.75','$\lambda_{y}$=0.75 $\lambda_{r}$=0.75','$\lambda_{y}$=1.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.00 $\lambda_{r}$=1.00','$\lambda_{y}$=0.25 $\lambda_{r}$=1.00','$\lambda_{y}$=0.50 $\lambda_{r}$=1.00','$\lambda_{y}$=0.75 $\lambda_{r}$=1.00','$\lambda_{y}$=1.00 $\lambda_{r}$=1.00'};
allmatrix0 = horzcat(squeeze([WelfareIRF(nbmodels,kf,1:5,1,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,1)]));
h = heatmap(xvalues,yvalues,allmatrix0','Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss functions';
%h.XLabel = 'Models';
h.YLabel = 'Output gap and interest rate weights';
h.CellLabelFormat = '%.2f';
h.GridVisible = 'off';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = xvalues;
hs.XAxis.TickLabelInterpreter = 'none';
hs.YAxis.TickValues = yvalues;
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;

f_name = strcat('fig_welfare_hm_y_r_',num2str(kf));
print(f_name,'-depsc2','-r0');

% all wage
set(groot,'defaulttextinterpreter','latex');  
set(groot,'defaultAxesTickLabelInterpreter','latex');  
set(groot,'defaultLegendInterpreter','latex'); 

hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'$\lambda_{y}$=0.00 $\lambda_{w}$=0.00','$\lambda_{y}$=0.25 $\lambda_{w}$=0.00','$\lambda_{y}$=0.50 $\lambda_{w}$=0.00','$\lambda_{y}$=0.75 $\lambda_{w}$=0.00','$\lambda_{y}$=1.00 $\lambda_{w}$=0.00','$\lambda_{y}$=0.00 $\lambda_{w}$=0.25','$\lambda_{y}$=0.25 $\lambda_{w}$=0.25','$\lambda_{y}$=0.50 $\lambda_{w}$=0.25','$\lambda_{y}$=0.75 $\lambda_{w}$=0.25','$\lambda_{y}$=1.00 $\lambda_{w}$=0.25','$\lambda_{y}$=0.00 $\lambda_{w}$=0.50','$\lambda_{y}$=0.25 $\lambda_{w}$=0.50','$\lambda_{y}$=0.50 $\lambda_{w}$=0.50','$\lambda_{y}$=0.75 $\lambda_{w}$=0.50','$\lambda_{y}$=1.00 $\lambda_{w}$=0.50','$\lambda_{y}$=0.00 $\lambda_{w}$=0.75','$\lambda_{y}$=0.25 $\lambda_{w}$=0.75','$\lambda_{y}$=0.50 $\lambda_{w}$=0.75','$\lambda_{y}$=0.75 $\lambda_{w}$=0.75','$\lambda_{y}$=1.00 $\lambda_{w}$=0.75','$\lambda_{y}$=0.00 $\lambda_{w}$=1.00','$\lambda_{y}$=0.25 $\lambda_{w}$=1.00','$\lambda_{y}$=0.50 $\lambda_{w}$=1.00','$\lambda_{y}$=0.75 $\lambda_{w}$=1.00','$\lambda_{y}$=1.00 $\lambda_{w}$=1.00'};
allmatrix1 = horzcat(squeeze([WelfareIRF(nbmodels,kf,1:5,1,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,5)]));
h=contourf(allmatrix1','LineStyle','none');
colormap(flipud(gray(256)));
contourcbar;
set(gca,'XTick',1:length(xvalues),'XTickLabel',xvalues);
set(gca,'YTick',1:length(yvalues),'YTickLabel',yvalues);
%set(get(gca, 'Title'), 'string', 'Spectrum of loss functions');
%set(get(gca, 'XLabel'), 'string', 'Models');
set(get(gca, 'YLabel'), 'string', 'Output gap and wage inflation weights');
f_name = strcat('fig_welfare_hm_y_w_',num2str(kf));
saveas(hmfig,f_name,'epsc');
set(groot,'defaulttextinterpreter','none');  
set(groot,'defaultAxesTickLabelInterpreter','none');  
set(groot,'defaultLegendInterpreter','none'); 

% all
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0 aa','0.25 aa','0.5 aa','0.75 aa','1 aa','0 ba','0.25 ba','0.5 ba','0.75 ba','1 ba','0 ca','0.25 ca','0.5 ca','0.75 ca','1 ca','0 da','0.25 da','0.5 da','0.75 da','1 da','0 ea','0.25 ea','0.5 ea','0.75 ea','1 ea','0 ab','0.25 ab','0.5 ab','0.75 ab','1 ab','0 bb','0.25 bb','0.5 bb','0.75 bb','1 bb','0 cb','0.25 cb','0.5 cb','0.75 cb','1 cb','0 db','0.25 db','0.5 db','0.75 db','1 db','0 eb','0.25 eb','0.5 eb','0.75 eb','1 eb','0 ac','0.25 ac','0.5 ac','0.75 ac','1 ac','0 bc','0.25 bc','0.5 bc','0.75 bc','1 bc','0 cc','0.25 cc','0.5 cc','0.75 cc','1 cc','0 dc','0.25 dc','0.5 dc','0.75 dc','1 dc','0 ec','0.25 ec','0.5 ec','0.75 ec','1 ec','0 ad','0.25 ad','0.5 ad','0.75 ad','1 ad','0 bd','0.25 bd','0.5 bd','0.75 bd','1 bd','0 cd','0.25 cd','0.5 cd','0.75 cd','1 cd','0 dd','0.25 dd','0.5 dd','0.75 dd','1 dd','0 ed','0.25 ed','0.5 ed','0.75 ed','1 ed','0 ae','0.25 ae','0.5 ae','0.75 ae','1 ae','0 be','0.25 be','0.5 be','0.75 be','1 be','0 ce','0.25 ce','0.5 ce','0.75 ce','1 ce','0 de','0.25 de','0.5 de','0.75 de','1 de','0 ee','0.25 ee','0.5 ee','0.75 ee','1 ee',};
allmatrix2 = horzcat(squeeze([WelfareIRF(nbmodels,kf,1:5,1,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,5)]));
h = heatmap(xvalues,yvalues,(allmatrix2'-0.13),'Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss functions';
%h.XLabel = 'Models';
h.YLabel = 'Possible weights';
h.GridVisible = 'off';

old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
%now we can get at the private properties XAxis and YAxis
hs.XAxis.TickValues = [];
hs.YAxis.TickValues = [];

f_name = strcat('fig_welfare_hm_allw_',num2str(kf));
print(f_name,'-depsc2','-r0');


% all radio
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
yvalues = {'0 aa','0.25 aa','0.5 aa','0.75 aa','1 aa','0 ba','0.25 ba','0.5 ba','0.75 ba','1 ba','0 ca','0.25 ca','0.5 ca','0.75 ca','1 ca','0 da','0.25 da','0.5 da','0.75 da','1 da','0 ea','0.25 ea','0.5 ea','0.75 ea','1 ea','0 ab','0.25 ab','0.5 ab','0.75 ab','1 ab','0 bb','0.25 bb','0.5 bb','0.75 bb','1 bb','0 cb','0.25 cb','0.5 cb','0.75 cb','1 cb','0 db','0.25 db','0.5 db','0.75 db','1 db','0 eb','0.25 eb','0.5 eb','0.75 eb','1 eb','0 ac','0.25 ac','0.5 ac','0.75 ac','1 ac','0 bc','0.25 bc','0.5 bc','0.75 bc','1 bc','0 cc','0.25 cc','0.5 cc','0.75 cc','1 cc','0 dc','0.25 dc','0.5 dc','0.75 dc','1 dc','0 ec','0.25 ec','0.5 ec','0.75 ec','1 ec','0 ad','0.25 ad','0.5 ad','0.75 ad','1 ad','0 bd','0.25 bd','0.5 bd','0.75 bd','1 bd','0 cd','0.25 cd','0.5 cd','0.75 cd','1 cd','0 dd','0.25 dd','0.5 dd','0.75 dd','1 dd','0 ed','0.25 ed','0.5 ed','0.75 ed','1 ed','0 ae','0.25 ae','0.5 ae','0.75 ae','1 ae','0 be','0.25 be','0.5 be','0.75 be','1 be','0 ce','0.25 ce','0.5 ce','0.75 ce','1 ce','0 de','0.25 de','0.5 de','0.75 de','1 de','0 ee','0.25 ee','0.5 ee','0.75 ee','1 ee',};
allmatrix2 = horzcat(squeeze([WelfareIRF(nbmodels,kf,1:5,1,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,1)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,2)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,3)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,4)]), squeeze([WelfareIRF(nbmodels,kf,1:5,1,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,2,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,3,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,4,5)]), squeeze([WelfareIRF(nbmodels,kf,1:5,5,5)]));
h=contourf(allmatrix2','LineStyle','none');
colormap(flipud(gray(256)));
contourcbar;
set(gca,'XTick',1:length(xvalues),'XTickLabel',xvalues);
set(gca,'YTick',1:length(yvalues),'YTickLabel',' ');
%set(get(gca, 'Title'), 'string', 'Spectrum of loss functions');
%set(get(gca, 'XLabel'), 'string', 'Models');
set(get(gca, 'YLabel'), 'string', 'Output gap, wage inflation and interest rate differential weights');

f_name = strcat('fig_welfare_hm_allwc_',num2str(kf));
print(f_name,'-depsc2','-r0');




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
%yvalues = {'$\lambda_{y}$=0.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.25 $\lambda_{r}$=0.00','$\lambda_{y}$=0.50 $\lambda_{r}$=0.00','$\lambda_{y}$=0.75 $\lambda_{r}$=0.00','$\lambda_{y}$=1.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.25 $\lambda_{r}$=0.25','$\lambda_{y}$=0.50 $\lambda_{r}$=0.25','$\lambda_{y}$=0.75 $\lambda_{r}$=0.25','$\lambda_{y}$=1.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.25 $\lambda_{r}$=0.50','$\lambda_{y}$=0.50 $\lambda_{r}$=0.50','$\lambda_{y}$=0.75 $\lambda_{r}$=0.50','$\lambda_{y}$=1.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.25 $\lambda_{r}$=0.75','$\lambda_{y}$=0.50 $\lambda_{r}$=0.75','$\lambda_{y}$=0.75 $\lambda_{r}$=0.75','$\lambda_{y}$=1.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.00 $\lambda_{r}$=1.00','$\lambda_{y}$=0.25 $\lambda_{r}$=1.00','$\lambda_{y}$=0.50 $\lambda_{r}$=1.00','$\lambda_{y}$=0.75 $\lambda_{r}$=1.00','$\lambda_{y}$=1.00 $\lambda_{r}$=1.00'};
yvalues = {'$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0'};
allmatrix0 = vertcat(squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,5)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,5)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,5)])');
h = heatmap(xvalues,yvalues,allmatrix0,'Colormap',colormap(flipud(gray)));
%h.Title = 'Spectrum of loss functions';
%h.XLabel = 'Models';
%h.YLabel = 'Output gap, interest rate differential, and wage inflation weights';
h.CellLabelFormat = '%.2f';
h.GridVisible = 'off';
old_warning_state = warning('off', 'MATLAB:structOnObject');
hs = struct(h);
warning(old_warning_state);
hs.XAxis.TickValues = xvalues;
hs.XAxis.TickLabelInterpreter = 'none';
hs.YAxis.TickValues = yvalues;
hs.YAxis.TickLabelInterpreter = 'latex';
hs.YAxis.FontSize = 8;

f_name = strcat('fig_loss_functions_irf_hm_all_',num2str(kf));
print(f_name,'-depsc2','-r0');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(groot,'defaulttextinterpreter','latex');  
set(groot,'defaultAxesTickLabelInterpreter','latex');  
set(groot,'defaultLegendInterpreter','latex'); 
hmfig = figure(fig_index); clf; cla; fig_index=fig_index+1;
xvalues = {'1','2','3','4','5','6','7','8','9','10','11','12'};
%yvalues = {'$\lambda_{y}$=0.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.25 $\lambda_{r}$=0.00','$\lambda_{y}$=0.50 $\lambda_{r}$=0.00','$\lambda_{y}$=0.75 $\lambda_{r}$=0.00','$\lambda_{y}$=1.00 $\lambda_{r}$=0.00','$\lambda_{y}$=0.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.25 $\lambda_{r}$=0.25','$\lambda_{y}$=0.50 $\lambda_{r}$=0.25','$\lambda_{y}$=0.75 $\lambda_{r}$=0.25','$\lambda_{y}$=1.00 $\lambda_{r}$=0.25','$\lambda_{y}$=0.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.25 $\lambda_{r}$=0.50','$\lambda_{y}$=0.50 $\lambda_{r}$=0.50','$\lambda_{y}$=0.75 $\lambda_{r}$=0.50','$\lambda_{y}$=1.00 $\lambda_{r}$=0.50','$\lambda_{y}$=0.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.25 $\lambda_{r}$=0.75','$\lambda_{y}$=0.50 $\lambda_{r}$=0.75','$\lambda_{y}$=0.75 $\lambda_{r}$=0.75','$\lambda_{y}$=1.00 $\lambda_{r}$=0.75','$\lambda_{y}$=0.00 $\lambda_{r}$=1.00','$\lambda_{y}$=0.25 $\lambda_{r}$=1.00','$\lambda_{y}$=0.50 $\lambda_{r}$=1.00','$\lambda_{y}$=0.75 $\lambda_{r}$=1.00','$\lambda_{y}$=1.00 $\lambda_{r}$=1.00'};
yvalues = {'$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=0.5','$\lambda_{y}$=0.0 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.0 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=0.5 $\lambda_{w}$=1.0','$\lambda_{y}$=0.0 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0','$\lambda_{y}$=0.5 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0','$\lambda_{y}$=1.0 $\lambda_{r}$=1.0 $\lambda_{w}$=1.0'};
allmatrix0 = vertcat(squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,1)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,3)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,1,5)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,3,5)])', squeeze([WelfareIRF(nbmodels,kf,1:2:5,5,5)])');
h = contourf(allmatrix0,'LineStyle','none');
colormap(flipud(gray(256)));
contourcbar;
set(gca,'XTick',1:length(xvalues),'XTickLabel',xvalues);
set(gca,'YTick',1:length(yvalues),'YTickLabel',yvalues);
%set(get(gca, 'Title'), 'string', 'Spectrum of loss functions','Interpreter','none');
%set(get(gca, 'XLabel'), 'string', 'Models','Interpreter','none');
set(groot,'defaulttextinterpreter','none');  
set(groot,'defaultAxesTickLabelInterpreter','none');  
set(groot,'defaultLegendInterpreter','none'); 

f_name = strcat('fig_loss_functions_irf_hm_allc_',num2str(kf));
print(f_name,'-depsc2','-r0');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;
end


for myperiodtoselect=1:4
close all;
fig_index = 1;

myfilenames={
'us0',
'us1',
'us2',
'us3'
};
filename=myfilenames{myperiodtoselect};

myshocks={
'ea',
'eb',
'eg',
'eqs',
'em',
'epinf',
'ew'
};

% for km=nbmodels
% for ks=nbshocks
% for knbirfs=nbirfs
% RIRFs5 (ks,km,myperiodtoselect,knbirfs)	= eval(['oo' filename num2str(km) '_.irfs.' myvariables{25} '_' myshocks{ks} '(knbirfs)'])/eval(['oo' filename num2str(km) '_.var(25,25)']);
% end
% end
% end


end

% Plotting impulse response functions

% set(0, 'DefaultAxesColorOrder',[0 0 0;1 0 0;0 1 0;0 0 1], 'DefaultAxesLineStyleOrder','-|--|:')

% hfig3 = figure(fig_index); clf; cla; fig_index=fig_index+1;
% i=1;
	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(6,:,1,nbirfs))'); axis tight; grid on;
	% title('1955-2017','FontSize',10);
	% ylabel({'Price';'markup'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(6,:,2,nbirfs))'); axis tight; grid on;
	% title('2007-2017','FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(6,:,3,nbirfs))'); axis tight; grid on;
	% title('1985-2007','FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(6,:,4,nbirfs))'); axis tight; grid on;
	% title('1955-1985','FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(5,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Monetary';'policy'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(5,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(5,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(5,:,4,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(7,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Wage';'markup'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(7,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(7,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(7,:,4,nbirfs))'); axis tight; grid on;
	
	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(1,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Technology'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(1,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(1,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(1,:,4,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(2,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Risk';'premium'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(2,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(2,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(2,:,4,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(4,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Investment';'specific'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(4,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(4,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(4,:,4,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(3,:,1,nbirfs))'); axis tight; grid on;
	% ylabel({'Government';'spending'},'FontSize',10);

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(3,:,2,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; plot(squeeze(RIRFs5(3,:,3,nbirfs))'); axis tight; grid on;

	% subplot(7,4,i); i=i+1; b = plot(squeeze(RIRFs5(3,:,4,nbirfs))'); axis tight; grid on;
	% hold off;
	
	% set(hfig3,'Position',[0 0 600 1000])

	% hfig3.PaperUnits = 'inches';
	% hfig3.PaperPosition = [0 0 10 13];
	% lbl = {'1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 '};
	% legendflex([b], lbl, 'ref', gcf,'anchor', {'s','n'},'buffer',[-5 30],'nrow',1,'fontsize',10,'box',['off']);
	% %set(gcf,'PaperUnits','inches','PaperPosition',[0 0 10 9])
	% f_name = strcat('fig_irfs_welfare');
	% print(f_name,'-depsc2','-r0');